'use strict';

var _multimatch = require('multimatch');

var _multimatch2 = _interopRequireDefault(_multimatch);

var _each = require('async/each');

var _each2 = _interopRequireDefault(_each);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function setOptions(opt) {

  // Set action to transform if `function` is passed in.
  // Pattern set to all since transform function should do the filtering.
  if (typeof opt === 'function') {
    return {
      action: 'transform',
      callback: opt,
      pattern: '**/*'
    };
  }

  // If any other action type,
  // Read and set defaults
  return {
    action: opt.action || 'append',
    pattern: opt.pattern || '**/*',
    value: opt.value || ''
  };
}

function applyStandardOperations(contents, options) {
  // Appends the string to the contents
  if (options.action === 'append') {
    return contents + options.value;
  }

  // Prepends the string to the contents
  if (options.action === 'prepend') {
    return options.value + contents;
  }

  // Prepends arr[0] and appends arr[1] to the contents
  // Will prepend by default.
  if (options.action === 'wrap') {
    if (Array.isArray(options.value)) {
      var pre = options.value[0] || '';
      var post = options.value[1] || '';
      return pre + contents + post;
    }

    return options.value + contents;
  }

  return contents;
}

function applyTransform(data, options, metalsmith) {
  if (typeof options.callback === 'function') {
    return options.callback(data, metalsmith);
  }
  return options.value(data, metalsmith);
}

function applyActions(data, options, metalsmith) {
  if (options.action === 'transform') {
    return applyTransform(data, options, metalsmith);
  }

  var contents = data.contents.toString();
  contents = applyStandardOperations(contents, options);
  data.contents = new Buffer(contents);
  return data;
}

function transform() {
  var opt = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var options = setOptions(opt == null ? {} : opt);

  return function (files, metalsmith, done) {
    var matchedFiles = (0, _multimatch2.default)(Object.keys(files), options.pattern);

    (0, _each2.default)(matchedFiles, function (file, callback) {
      var data = Object.assign({}, files[file]);
      files[file] = applyActions(data, options, metalsmith);
      callback();
    }, done);
  };
}

module.exports = transform;